@@ -26,16 +26,17 @@ def db(app):
     # template1 database in special AUTOCOMMIT isolation level.
     dburl = copy(db.engine.url)
     dburl.database = 'template1'
-    with create_engine(dburl).connect() as connection:
-        connection.execution_options(isolation_level='AUTOCOMMIT')
-        connection.execute('DROP DATABASE IF EXISTS {}'.format(dbname))
-        connection.execute('CREATE DATABASE {}'.format(dbname))
+    if ':memory:' not in dbname:
+        with create_engine(dburl).connect() as connection:
+            connection.execution_options(isolation_level='AUTOCOMMIT')
+            connection.execute('DROP DATABASE IF EXISTS {}'.format(dbname))
+            connection.execute('CREATE DATABASE {}'.format(dbname))
     db.create_all()
     db_hook_event_listeners()
     return db
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def session(db, monkeypatch):
     """Patch Flask-SQLAlchemy to use a specific connection"""
     connection = db.engine.connect()
@@ -51,7 +52,7 @@ def session(db, monkeypatch):
     connection.close()
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def client(app):
     """A Flask test client. An instance of :class:`flask.testing.TestClient`
     by default.
@@ -71,16 +72,6 @@ def enable_ssl(app, monkeypatch):
     monkeypatch.setitem(app.config, 'AUTH_METHOD', 'SSL')
 
 
-@pytest.fixture()
-def enable_permission_mapping(app, monkeypatch):
-    monkeypatch.setitem(app.config, 'PERMISSION_MAPPING',
-                        {
-                            "^testcase1.*": {"groups": ["factory-2-0"], "users": []}, # noqa
-                            "^testcase2.*": {"groups": [], "users": ["foo"]}, # noqa
-                            "^testcase4.*": {"groups": [], "users": []} # noqa
-                        })
-
-
 @pytest.fixture()
 def enable_ldap_host(app, monkeypatch):
     monkeypatch.setitem(app.config, 'LDAP_HOST', 'ldap://ldap.something.com')
